@@ -257,6 +257,7 @@ void
 z_version(void)
 {
   printf("Zorp %s\n"
+         "Revision: %s\n"
          "Compile-Date: %s %s\n"
          "Config-Date: %s\n"
          "Trace: %s\n"
@@ -268,11 +269,14 @@ z_version(void)
          "Linux22-Tproxy: %s\n"
          "Conntrack: %s\n\n"
          "%s",
-         VERSION, __DATE__, __TIME__,
+         VERSION, 
+         ZORP_SOURCE_REVISION,
+         __DATE__, __TIME__,
          ZORP_CONFIG_DATE,
          ON_OFF_STR(ENABLE_TRACE),
          ON_OFF_STR(ENABLE_DEBUG),
          ON_OFF_STR(ENABLE_IPOPTIONS),
+         ON_OFF_STR(ENABLE_IPFILTER_TPROXY),
          ON_OFF_STR(ENABLE_NETFILTER_TPROXY),
          ON_OFF_STR(ENABLE_NETFILTER_LINUX22_FALLBACK),
          ON_OFF_STR(ENABLE_LINUX22_TPROXY),
